@@ -80,6 +80,9 @@ class ListAttributeAccessor:
         self._attribute = attribute
         self.mapping = persistent
 
+    def __repr__(self):
+        return str(list(self))
+
     def __iter__(self):
         return (self._attribute.deserialize(item) for item in self.mapping)
 
@@ -278,6 +281,9 @@ class DictAttributeAccessor:
         self._attribute = attribute
         self.mapping = persistent
 
+    def __repr__(self):
+        return str(dict(self))
+
     def __setitem__(self, key, value):
         self.mapping[key] = self._attribute.serialize(value)
 
@@ -464,6 +470,9 @@ class SetAttributeAccessor:
         self._attribute = attribute
         self.mapping = persistent
 
+    def __repr__(self):
+        return str(set(self))
+
     def add(self, item):
         self.mapping.add(self._attribute.serialize(item))
 
@@ -610,13 +619,37 @@ class SetAttribute(sheraf.attributes.simples.TypedAttribute):
         deletion=False,
         replacement=False,
     ):
-        old_value_backup = set(old_value)
+        serialized_old_value = {
+            self.attribute.serialize(item) if self.attribute else item
+            for item in old_value
+        }
+        serialized_new_value = {
+            self.attribute.serialize(item) if self.attribute else item
+            for item in new_value
+        }
+
         if addition:
-            for item in set(new_value) & (set(new_value) ^ old_value_backup):
-                old_value.add(item)
+            to_add = serialized_new_value & (
+                serialized_new_value ^ serialized_old_value
+            )
 
         if deletion:
-            for item in old_value_backup & (old_value_backup ^ set(new_value)):
-                old_value.remove(item)
+            to_del = serialized_old_value & (
+                serialized_old_value ^ serialized_new_value
+            )
 
-        return old_value
+        if addition:
+            for item in to_add:
+                if self.attribute:
+                    serialized_old_value.add(self.attribute.serialize(item))
+                else:
+                    serialized_old_value.add(item)
+
+        if deletion:
+            for item in to_del:
+                if self.attribute:
+                    serialized_old_value.remove(self.attribute.serialize(item))
+                else:
+                    serialized_old_value.remove(item)
+
+        return serialized_old_value
