@@ -1,6 +1,6 @@
 import inspect
 import sheraf
-from sheraf.models.indexation import model_from_table
+from sheraf.models.indexation import BaseIndexedModel
 from sheraf.attributes import Attribute
 from sheraf.attributes.collections import ListAttribute, SetAttribute
 
@@ -196,12 +196,23 @@ class ModelAttribute(ModelLoader, Attribute):
     def deserialize(self, value):
         if isinstance(value, tuple):
             table, id_ = value
-            model = model_from_table(table)
+            model = BaseIndexedModel.from_table(table)
+            if model is None:
+                self.check_model()
+                model = BaseIndexedModel.from_table(table)
+
         else:
+            id_ = value
             model = (
                 self.model[0] if isinstance(self.model, (list, tuple)) else self.model
             )
-            id_ = value
+            if model is None:
+                self.check_model()
+                model = (
+                    self.model[0]
+                    if isinstance(self.model, (list, tuple))
+                    else self.model
+                )
 
         try:
             return model.read(id_)
@@ -222,6 +233,9 @@ class ModelAttribute(ModelLoader, Attribute):
         elif self.model and isinstance(value, dict):
             return self.model.create(**value).identifier
 
+        elif isinstance(value, tuple):
+            return value
+
         else:
             try:
                 return self.model.read(value).identifier
