@@ -319,7 +319,9 @@ class BaseIndexedModel(BaseModel, metaclass=BaseIndexedModelMetaclass):
             )
 
     @classmethod
-    def index_table_rebuild(cls, *args, callback=None):
+    def index_table_rebuild(
+        cls, *args, callback=None, reset=True, start=None, end=None
+    ):
         """
         Resets a model indexation tables.
 
@@ -331,7 +333,29 @@ class BaseIndexedModel(BaseModel, metaclass=BaseIndexedModelMetaclass):
                       resetted.
         :param callback: A callback that is called each item a model instance is
                          iterated.
+        :param reset: If `True` the index tables are deleted before reindexaxtion.
+                      Defaults to `True`.
         """
+        if reset:
+            cls.index_table_reset(*args)
+
+        if not args:
+            indexes = cls.indexes.values()
+        else:
+            indexes = [
+                index for index_name, index in cls.indexes.items() if index_name in args
+            ]
+
+        for i, m in enumerate(cls.all()[start:end]):
+            for index in indexes:
+                if not index.details.primary:
+                    index.add_item(m)
+
+            if callback and callback(i, m) is False:
+                break
+
+    @classmethod
+    def index_table_reset(cls, *args):
         if not args:
             indexes = cls.indexes.values()
         else:
@@ -340,18 +364,8 @@ class BaseIndexedModel(BaseModel, metaclass=BaseIndexedModelMetaclass):
             ]
 
         for index in indexes:
-            if index.details.primary:
-                continue
-
-            index.delete()
-
-        for i, m in enumerate(cls.all()):
-            for index in indexes:
-                if not index.details.primary:
-                    index.add_item(m)
-
-            if callback and callback(i, m) is False:
-                break
+            if not index.details.primary:
+                index.delete()
 
     @classmethod
     def filter(cls, predicate=None, **kwargs):
@@ -418,6 +432,12 @@ class BaseIndexedModel(BaseModel, metaclass=BaseIndexedModelMetaclass):
         """
         return cls.filter(*args, **kwargs).get()
 
+    @classmethod
+    def from_table(cls, table_name):
+        if table_name not in IndexedModelMetaclass.tables:
+            return None
+        return IndexedModelMetaclass.tables[table_name][1]
+
     def __repr__(self):
         try:
             identifier = (
@@ -540,7 +560,10 @@ class BaseIndexedModel(BaseModel, metaclass=BaseIndexedModelMetaclass):
 
             index_manager = self.indexes[index.key]
             index_manager.update_item(
-                self, old_index_values[index], new_index_values, ignore_errors=True
+                self,
+                old_index_values[index],
+                new_index_values,
+                ignore_errors=ignore_errors,
             )
 
     @property
@@ -737,12 +760,6 @@ class IndexedModelMetaclass(BaseIndexedModelMetaclass):
         return klass
 
 
-def model_from_table(table_name):
-    if table_name not in IndexedModelMetaclass.tables:
-        return None
-    return IndexedModelMetaclass.tables[table_name][1]
-
-
 class IndexedModel(BaseIndexedModel, metaclass=IndexedModelMetaclass):
     """
     :class:`~sheraf.models.indexation.IndexedModel` are the top-level
